@@ -88,8 +88,8 @@ public class AllPluginsLoaded extends AbstractMBeanCLI<Void> {
     }
 
     @Override
-    protected boolean requiresAdministrativePermission() {
-        return false;
+    protected Boolean requiresAdministrativePermission() {
+        return Boolean.FALSE;
     }
 
     @Override
@@ -122,5 +122,4 @@ public class AllPluginsLoaded extends AbstractMBeanCLI<Void> {
         }
         return null;
     }
-
 }
