@@ -127,7 +127,7 @@ public final class CheckCountsConsistency extends ContextAbstraction {
 
             System.out.println("Counts successfully checked");
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, null, e, parser);
         }
     }
