@@ -75,7 +75,7 @@ public class DisableAll extends ContextAbstraction {
 
             displayDisabledMessage(null, null, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, null, e, parser);
         }
     }
