@@ -72,7 +72,7 @@ public class EnableAll extends ContextAbstraction {
 
             displayEnabledMessage(null, null, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, null, e, parser);
         }
 
