@@ -108,7 +108,7 @@ public class GetContextCapabilities extends ContextAbstraction {
 
                 successtext = nameOrIdSetInt(this.ctxid, this.contextname, "context");
 
-            } catch (final RuntimeException e) {
+            } catch (RuntimeException e) {
                 printError(null, null, e.getClass().getSimpleName() + ": " + e.getMessage(), parser);
                 sysexit(1);
             }
@@ -129,7 +129,7 @@ public class GetContextCapabilities extends ContextAbstraction {
                 System.out.println(sb.toString());
             }
 
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, null, e, parser);
             sysexit(SYSEXIT_COMMUNICATION_ERROR);
         }
