@@ -91,7 +91,7 @@ public class GetModuleAccess extends ContextAbstraction {
 
             // exit application
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, null, e, parser);
         }
     }
