@@ -87,7 +87,7 @@ public class MoveContextDatabase extends ContextAbstraction {
 
             displayMovedMessage(successcontext, null, "to database " + (db.getId() != null ? db.getId() : db.getName()) + " scheduled as job " + jobId, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             // In this special case the second parameter is not the context id but the database id
             // this also applies to all following error outputting methods
             // see com.openexchange.admin.console.context.ContextHostingAbstraction.printFirstPartOfErrorText(Integer, Integer)
