@@ -110,8 +110,8 @@ public class DeleteContextGroup extends AbstractRmiCLI<Void> {
     }
 
     @Override
-    protected boolean requiresAdministrativePermission() {
-        return true;
+    protected Boolean requiresAdministrativePermission() {
+        return Boolean.TRUE;
     }
 
     @Override
