@@ -121,7 +121,7 @@ public abstract class ChangeCore extends GroupAbstraction {
 
             displayChangedMessage(successtext, ctxid, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, ctxid, e, parser);
         }
     }
