@@ -107,7 +107,7 @@ public abstract class ListCore extends GroupAbstraction {
             }
 
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, ctxid, e, parser);
             sysexit(1);
         }
