@@ -130,10 +130,10 @@ public class JobControl extends BasicCommandlineOptions {
             } else if (null != detailValue) {
                 try {
                     oxtask.getTaskResults(ctx, auth, Integer.parseInt(detailValue));
-                } catch (final InterruptedException e) {
+                } catch (InterruptedException e) {
                     System.err.println("This job was interrupted with the following exception: ");
                     e.printStackTrace();
-                } catch (final ExecutionException e) {
+                } catch (ExecutionException e) {
                     System.err.println("The execution of this job was aborted by the following exception: ");
                     e.getCause().printStackTrace();
                 }
@@ -146,47 +146,47 @@ public class JobControl extends BasicCommandlineOptions {
                         .append(")"));
                 parser.printUsage();
             }
-        } catch (final java.rmi.ConnectException neti) {
+        } catch (java.rmi.ConnectException neti) {
             printError(neti.getMessage(), parser);
             sysexit(SYSEXIT_COMMUNICATION_ERROR);
-        } catch (final java.lang.NumberFormatException num) {
+        } catch (java.lang.NumberFormatException num) {
             printInvalidInputMsg("Ids must be numbers!");
             sysexit(1);
-        } catch (final MalformedURLException e) {
+        } catch (MalformedURLException e) {
             printServerException(e,parser);
             sysexit(1);
-        } catch (final RemoteException e) {
+        } catch (RemoteException e) {
             printServerException(e,parser);
             sysexit(SYSEXIT_REMOTE_ERROR);
-        } catch (final NotBoundException e) {
+        } catch (NotBoundException e) {
             printServerException(e,parser);
             sysexit(1);
-        } catch (final CLIParseException e) {
+        } catch (CLIParseException e) {
             printError("Parsing command-line failed : " + e.getMessage(), parser);
             parser.printUsage();
             sysexit(SYSEXIT_ILLEGAL_OPTION_VALUE);
-        } catch (final CLIIllegalOptionValueException e) {
+        } catch (CLIIllegalOptionValueException e) {
             printError("Illegal option value : " + e.getMessage(), parser);
             parser.printUsage();
             sysexit(SYSEXIT_ILLEGAL_OPTION_VALUE);
-        } catch (final CLIUnknownOptionException e) {
+        } catch (CLIUnknownOptionException e) {
             printError("Unrecognized options on the command line: " + e.getMessage(), parser);
             parser.printUsage();
             sysexit(SYSEXIT_UNKNOWN_OPTION);
-        } catch (final MissingOptionException e) {
+        } catch (MissingOptionException e) {
             printError(e.getMessage(), parser);
             parser.printUsage();
             sysexit(SYSEXIT_MISSING_OPTION);
-        } catch (final InvalidDataException e) {
+        } catch (InvalidDataException e) {
             printServerException(e,parser);
             sysexit(SYSEXIT_INVALID_DATA);
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             printServerException(e, parser);
             sysexit(SYSEXIT_INVALID_CREDENTIALS);
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             printServerException(e, parser);
             sysexit(SYSEXIT_SERVERSTORAGE_ERROR);
-        } catch (final TaskManagerException e) {
+        } catch (TaskManagerException e) {
             printServerException(e, parser);
             sysexit(1);
         }
