@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,6 +58,7 @@ import com.openexchange.admin.rmi.dataobjects.User;
 import com.openexchange.admin.rmi.exceptions.DatabaseUpdateException;
 import com.openexchange.admin.rmi.exceptions.InvalidCredentialsException;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
+import com.openexchange.admin.rmi.exceptions.MissingOptionException;
 import com.openexchange.admin.rmi.exceptions.NoSuchContextException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 
@@ -69,6 +70,7 @@ public abstract class ExistsCore extends UserAbstraction {
         // required
         setIdOption(parser);
         setUsernameOption(parser, NeededQuadState.eitheror);
+        setDisplayNameOption(parser, NeededQuadState.eitheror);
     }
 
     protected final void commonfunctions(final AdminParser parser, final String[] args) {
@@ -78,21 +80,29 @@ public abstract class ExistsCore extends UserAbstraction {
         try {
             parser.ownparse(args);
 
-            final Context ctx = contextparsing(parser);
-            final User usr = new User();
+            // Parse arguments
+            Context ctx = contextparsing(parser);
+            User usr = new User();
             parseAndSetUserId(parser, usr);
             parseAndSetUsername(parser, usr);
-            final Credentials auth = credentialsparsing(parser);
+            parseAndSetDisplayName(parser, usr);
+            Credentials auth = credentialsparsing(parser);
+
+            // Get RMI stub
+            OXUserInterface oxusr = getUserInterface();
 
-            // get rmi ref
-            final OXUserInterface oxusr = getUserInterface();
             String usrident;
-            if( null != usr.getId() ) {
+            if (null != usr.getId()) {
                 usrident = String.valueOf(usr.getId());
-            } else {
+            } else if (null != usr.getName()) {
                 usrident = usr.getName();
+            } else if (null != usr.getDisplay_name()) {
+                usrident = new StringBuilder(usr.getDisplay_name().length() + 2).append('"').append(usr.getDisplay_name()).append('"').toString();
+            } else {
+                throw new MissingOptionException("Neither identifier, name nor display name given");
             }
-            if( maincall(parser, oxusr, ctx, usr, auth) ) {
+
+            if (maincall(parser, oxusr, ctx, usr, auth)) {
                 System.out.println("User " + usrident + " exists");
                 sysexit(0);
             } else {
@@ -100,7 +110,7 @@ public abstract class ExistsCore extends UserAbstraction {
                 sysexit(1);
             }
 
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, ctxid, e, parser);
         }
     }
