@@ -92,7 +92,7 @@ public class ChangeDatabase extends DatabaseAbstraction {
 
             displayChangedMessage(successtext, null, parser);
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(successtext, null, e, parser);
         }
     }
