@@ -131,7 +131,7 @@ public final class CheckDatabase extends DatabaseAbstraction {
             }
 
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, ctxid, e, parser);
         }
 
