@@ -97,7 +97,7 @@ public class ListFilestore extends FilestoreAbstraction {
                 sysoutOutput(filestores);
             }
             sysexit(0);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printErrors(null, ctxid, e, parser);
         }
     }
