@@ -50,6 +50,7 @@
 package com.openexchange.admin.rmi.dataobjects;
 
 import java.io.Serializable;
+import java.util.Arrays;
 
 /**
  * This object must be send with every method call in ox rmi interface!
@@ -71,6 +72,8 @@ public class Credentials implements Serializable {
 
     private String passwordMech;
 
+    private byte[] salt;
+
     /**
      * Creates a new instance of the object
      */
@@ -145,6 +148,24 @@ public class Credentials implements Serializable {
         this.passwordMech = passwordMech;
     }
 
+    /**
+     * Gets the salt
+     *
+     * @return The salt
+     */
+    public byte[] getSalt() {
+        return salt;
+    }
+
+    /**
+     * Sets the salt
+     *
+     * @param salt The salt to set
+     */
+    public void setSalt(byte[] salt) {
+        this.salt = salt;
+    }
+
     /**
      * Sets all members to default values
      */
@@ -164,8 +185,7 @@ public class Credentials implements Serializable {
 
         final StringBuilder retValue = new StringBuilder();
 
-        retValue.append("Credentials ( ").append(super.toString()).append(TAB).append("login = ").append(this.login).append(TAB).append(
-            "passwordMech = ").append(this.passwordMech).append(" )");
+        retValue.append("Credentials ( ").append(super.toString()).append(TAB).append("login = ").append(this.login).append(TAB).append("passwordMech = ").append(this.passwordMech).append(TAB).append(" )");
 
         return retValue.toString();
     }
@@ -177,6 +197,7 @@ public class Credentials implements Serializable {
         result = prime * result + ((login == null) ? 0 : login.hashCode());
         result = prime * result + ((password == null) ? 0 : password.hashCode());
         result = prime * result + ((passwordMech == null) ? 0 : passwordMech.hashCode());
+        result = prime * result + ((salt == null) ? 0 : Arrays.hashCode(salt));
         return result;
     }
 
@@ -213,6 +234,13 @@ public class Credentials implements Serializable {
         } else if (!passwordMech.equals(other.passwordMech)) {
             return false;
         }
+        if (salt == null) {
+            if (other.salt != null) {
+                return false;
+            }
+        } else if (!Arrays.equals(salt, other.salt)) {
+            return false;
+        }
         return true;
     }
 }
