@@ -138,9 +138,9 @@ public class Server implements Serializable, NameAndIdObject {
                     ret.append(ob);
                     ret.append("\n");
                 }
-            } catch (final IllegalArgumentException e) {
+            } catch (IllegalArgumentException e) {
                 ret.append("IllegalArgument\n");
-            } catch (final IllegalAccessException e) {
+            } catch (IllegalAccessException e) {
                 ret.append("IllegalAccessException\n");
             }
         }
@@ -166,9 +166,6 @@ public class Server implements Serializable, NameAndIdObject {
         return nameset;
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#hashCode()
-     */
     @Override
     public int hashCode() {
         final int prime = 31;
@@ -180,9 +177,6 @@ public class Server implements Serializable, NameAndIdObject {
         return result;
     }
 
-    /* (non-Javadoc)
-     * @see java.lang.Object#equals(java.lang.Object)
-     */
     @Override
     public boolean equals(Object obj) {
         if (this == obj) {
