@@ -100,7 +100,7 @@ public abstract class OXUtilStorageInterface {
                     if (null != className) {
                         try {
                             implementingClass = Class.forName(className).asSubclass(OXUtilStorageInterface.class);
-                        } catch (final ClassNotFoundException e) {
+                        } catch (ClassNotFoundException e) {
                             log.error("", e);
                             throw new StorageException(e);
                         }
@@ -115,22 +115,22 @@ public abstract class OXUtilStorageInterface {
                         cons = implementingClass.getConstructor(new Class[] {});
                         inst = cons.newInstance(new Object[] {});
                         instance = inst;
-                    } catch (final SecurityException e) {
+                    } catch (SecurityException e) {
                         log.error("", e);
                         throw new StorageException(e);
-                    } catch (final NoSuchMethodException e) {
+                    } catch (NoSuchMethodException e) {
                         log.error("", e);
                         throw new StorageException(e);
-                    } catch (final IllegalArgumentException e) {
+                    } catch (IllegalArgumentException e) {
                         log.error("", e);
                         throw new StorageException(e);
-                    } catch (final InstantiationException e) {
+                    } catch (InstantiationException e) {
                         log.error("", e);
                         throw new StorageException(e);
-                    } catch (final IllegalAccessException e) {
+                    } catch (IllegalAccessException e) {
                         log.error("", e);
                         throw new StorageException(e);
-                    } catch (final InvocationTargetException e) {
+                    } catch (InvocationTargetException e) {
                         log.error("", e);
                         throw new StorageException(e);
                     }
